@@ -12,6 +12,7 @@ from typing import List, Dict, Optional, Tuple, Any
 
 from gql import Client, gql
 from gql.transport.aiohttp import AIOHTTPTransport
+from gql.transport.requests import RequestsHTTPTransport
 from gql.client import DocumentNode
 
 from transform_tools.validate import (
@@ -62,12 +63,17 @@ class BaseInterface:
     Assumes that authorization and GraphQL query pattern are the same across Backend, and MQL APIs
     """
 
-    def __init__(self, auth_header: Dict[str, str], rest_api_url: str) -> None:  # noqa: D
+    def __init__(self, auth_header: Dict[str, str], rest_api_url: str, use_async: bool = False) -> None:  # noqa: D
         self.rest_api_url = rest_api_url
         self.auth_header = auth_header
 
+        gql_transport = (
+            AIOHTTPTransport(url=self.graphql_api_url, headers=self.auth_header)
+            if use_async
+            else RequestsHTTPTransport(url=self.graphql_api_url, retries=2, headers=self.auth_header)
+        )
         self.gql_client = Client(
-            transport=AIOHTTPTransport(url=self.graphql_api_url, headers=self.auth_header),
+            transport=gql_transport,  # type: ignore
             fetch_schema_from_transport=False,
             execute_timeout=90,  # 1.5 minute
         )
@@ -124,8 +130,10 @@ class BaseInterface:
 
 
 class BackendInterface(BaseInterface):  # noqa: D
-    def __init__(self, auth_header: Dict[str, str], rest_api_url: str = TRANSFORM_PROD_API) -> None:  # noqa: D
-        super(BackendInterface, self).__init__(auth_header, rest_api_url)
+    def __init__(  # noqa: D
+        self, auth_header: Dict[str, str], rest_api_url: str = TRANSFORM_PROD_API, use_async: bool = False
+    ) -> None:
+        super(BackendInterface, self).__init__(auth_header, rest_api_url, use_async)
 
     def validate_configs(self, config_dir: str) -> ModelKey:
         """Finds and validates yaml configs in the provided directory"""
@@ -430,8 +438,8 @@ class BackendInterface(BaseInterface):  # noqa: D
 
 
 class MQLInterface(BaseInterface):  # noqa: D
-    def __init__(self, auth_header: Dict[str, str], query_server_url: str) -> None:  # noqa: D
-        super(MQLInterface, self).__init__(auth_header, query_server_url)
+    def __init__(self, auth_header: Dict[str, str], query_server_url: str, use_async: bool = False) -> None:  # noqa: D
+        super(MQLInterface, self).__init__(auth_header, query_server_url, use_async)
 
     def __common_query_input_params(  # type: ignore [misc]
         self,
